package com.cheesr.layers.api;

import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.net.ServerSocket;
import java.net.Socket;
import java.util.concurrent.Callable;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class RemoteApiServer {

    private static final Logger LOGGER = LoggerFactory.getLogger(RemoteApiServer.class);
    public static final int PORT = 9090;

    public void start() {
        Thread tr = new Thread(new Runnable() {
            public void run() {
                try {
                    ServerSocket ss = new ServerSocket(PORT);
                    try {
                        run(ss);
                    } finally {
                        ss.close();
                    }
                } catch (IOException ex) {
                    LOGGER.warn("ApiServer failed to initialize", ex);
                }
            }

            private void run(ServerSocket ss) throws IOException {
                while (true) {
                    Socket s = ss.accept();
                    try {
                        try {
                            execute(s);
                        } finally {
                            s.close();
                        }
                    } catch (IOException ex) {
                        LOGGER.warn("Failed API call", ex);
                    }
                }
            };
        });
        tr.setDaemon(true);
        tr.start();
        LOGGER.info("Remote Api Server listening");
    }

    public void execute(Socket s) throws IOException {
        ObjectInputStream in = new ObjectInputStream(s.getInputStream());
        Object result = null;
        try {
            Callable<?> r = (Callable<?>) in.readObject();
            result = r.call();
        } catch (Exception ex) {
            LOGGER.warn("Failed API call", ex);
            result = ex;
        }
        ObjectOutputStream out = new ObjectOutputStream(s.getOutputStream());
        out.writeObject(result);
    }
}
