package com.cheesr.layers.domain.product;

import java.io.Serializable;

import javax.persistence.Column;
import javax.persistence.DiscriminatorColumn;
import javax.persistence.DiscriminatorType;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.Inheritance;
import javax.persistence.InheritanceType;
import javax.persistence.Table;
import javax.persistence.Version;

@Entity
@Table(name = "PRODUCTS")
@Inheritance(strategy = InheritanceType.SINGLE_TABLE)
@DiscriminatorColumn(name = "productType", discriminatorType = DiscriminatorType.STRING)
public abstract class Product implements Serializable {

    @Id
    @GeneratedValue(strategy = GenerationType.AUTO)
    private Long id;
    @Version
    @Column(name = "version", nullable = false)
    private Long version;
    @Column(name = "name", nullable = false, length = 64)
    private String name;
    @Column(name = "description", nullable = false, length = 255)
    private String description;
    @Column(name = "price", nullable = false, length = 8, precision = 2)
    private double price;

    public Product() {
        // For Hibernate
    }

    public Product(String name, String description, double price) {
        this();
        this.name = name;
        this.description = description;
        this.price = price;
    }

    public long getId() {
        return id;
    }

    public long getVersion() {
        return version;
    }

    public String getDescription() {
        return description;
    }

    public String getName() {
        return name;
    }

    public double getPrice() {
        return price;
    }

    public void setName(String name) {
        this.name = name;
    }

    @Override
    public boolean equals(Object obj) {
        if ((obj instanceof Product) && (this.id != null)) {
            return ((Product) obj).id.equals(this.id);
        } else {
            return super.equals(obj);
        }
    }

    @Override
    public int hashCode() {
        return (this.id == null ? super.hashCode() : id.intValue());
    }
}
