package com.cheesr.layers.web;

import org.apache.wicket.Page;
import org.apache.wicket.Request;
import org.apache.wicket.Response;
import org.apache.wicket.Session;
import org.apache.wicket.protocol.http.WebApplication;
import org.apache.wicket.spring.injection.annot.SpringComponentInjector;

import com.cheesr.layers.web.pages.CheesePage;
import com.cheesr.layers.web.pages.OrdersPage;

/**
 * Application object for your web application. 
 */
public class BadCheesrApplication extends WebApplication {

    /**
     * Configuration type.
     */
    private String configurationType;

    /**
     * {@inheritDoc}
     */
    @Override
    protected void init() {
        super.init();
        configureComponentInjector();
        mountBookmarkablePage("/orders", OrdersPage.class);
    }

    /**
     * Inject a spring component instantiation listener.
     */
    protected void configureComponentInjector() {
        this.addComponentInstantiationListener(new SpringComponentInjector(this));
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public String getConfigurationType() {
        return configurationType != null ? configurationType : super.getConfigurationType();
    }

    /**
     * Modify the configuration type.
     * @param configurationType Configuration type to set
     */
    public void setConfigurationType(String configurationType) {
        this.configurationType = configurationType;
    }

    /**
     * Indicate that Index is the home page for this application.
     * @return The home page, which is Index.
     */
    @Override
    public Class<? extends Page> getHomePage() {
        return CheesePage.class;
    }

    /**
     * Return a session object to hold the models for each user of this application.
     * @param request The http request.
     * @param response The http response. 
     * @return The session instance for this user. 
     */
    @Override
    public Session newSession(Request request, Response response) {
        return new BadCheesrSession(this, request);
    }

    /**
     * Return this webapp. Using this, you can get the session for your current user instance.
     * 
     * @return The webapp.
     */
    public static BadCheesrApplication get() {
        return (BadCheesrApplication) WebApplication.get();
    }
}