package com.cheesr.layers.web;

import java.io.IOException;

import javax.servlet.FilterChain;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.LoggerFactory;
import org.springframework.web.filter.OncePerRequestFilter;

/**
 * The orders page may only be accessed by some one who has the Role: ADMIN header set.
 * (We'll assume a centralized authentication service that augments HTTP requests with additional headers).
 * If you want to set the header yourself, use the Modify Headers Firefox plugin.
 */
public class BadCheesrAuthorizationFilter extends OncePerRequestFilter {

    @Override
    protected void doFilterInternal(HttpServletRequest request, HttpServletResponse response, FilterChain filterChain) throws ServletException, IOException {
        if (request.getServletPath().endsWith("/orders")) {
            if (!"ADMIN".equals(request.getHeader("Role"))) {
                LoggerFactory.getLogger(BadCheesrApplication.class).info(String.format("Unauthorized access to '%s'", request.getServletPath()));
                response.sendError(HttpServletResponse.SC_UNAUTHORIZED);
                return;
            }
        }
        filterChain.doFilter(request, response);
    }

}
