package com.cheesr.layers.web;

import java.io.IOException;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.parsers.ParserConfigurationException;
import javax.xml.transform.Transformer;
import javax.xml.transform.TransformerException;
import javax.xml.transform.TransformerFactory;
import javax.xml.transform.dom.DOMSource;
import javax.xml.transform.stream.StreamResult;

import org.slf4j.LoggerFactory;
import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.Node;
import org.xml.sax.InputSource;
import org.xml.sax.SAXException;

public class XmlServlet extends HttpServlet {

    private DocumentBuilder builder;
    private TransformerFactory transformerFactory;

    public XmlServlet() {
        try {
            DocumentBuilderFactory dbFactory = DocumentBuilderFactory.newInstance();
            builder = dbFactory.newDocumentBuilder();
            transformerFactory = TransformerFactory.newInstance();
        } catch (ParserConfigurationException e) {
            throw new RuntimeException("Unable to initialize XML Parser");
        }
    }

    @Override
    protected void doPost(HttpServletRequest req, HttpServletResponse resp) throws ServletException, IOException {
        try {
            Document result = builder.newDocument();
            Document doc = builder.parse(new InputSource(req.getReader()));
            Element elem = doc.getDocumentElement();
            elem.normalize();
            if ("cheese".equals(elem.getTagName())) {
                // Ugh xml processing is hard. I'll leave this for now and come back later.
                result.appendChild(result.createElement("cheeses"));
            } else if ("wine".equals(elem.getTagName())) {
                result.appendChild(result.createElement("wines"));
            } else {
                Element element = result.createElement("error");
                element.appendChild(result.createTextNode("unknown node, expected cheese or wine. Not:"));
                // copy back the request for easy debugging.
                Node cloneNode = elem.cloneNode(true);
                element.appendChild(result.importNode(cloneNode, true));
                result.appendChild(element);
            }
            Transformer transformer = transformerFactory.newTransformer();
            transformer.transform(new DOMSource(result), new StreamResult(resp.getWriter()));
        } catch (SAXException e) {
            LoggerFactory.getLogger(getClass()).warn("Parse error", e);
            resp.sendError(500);
        } catch (TransformerException e) {
            LoggerFactory.getLogger(getClass()).warn("Transform error", e);
            resp.sendError(500);
        }
    }
}
