package com.cheesr.layers.web.pages;

import org.apache.wicket.markup.html.form.Button;
import org.apache.wicket.markup.html.form.Form;
import org.apache.wicket.markup.html.form.TextField;
import org.apache.wicket.markup.html.link.Link;
import org.apache.wicket.markup.html.panel.FeedbackPanel;
import org.apache.wicket.model.PropertyModel;

import com.cheesr.layers.domain.order.Address;
import com.cheesr.layers.domain.order.Order;
import com.cheesr.layers.web.panels.ShoppingCartPanel;
import com.cheesr.layers.web.validators.EmailValidator;

/**
 * The Checkout page allows you to enter the billing address and shows list of cheeses purchased.
 */
public class CheckoutPage extends CheesrPage {

    public CheckoutPage() {
        Form<String> form = new Form<String>("form");
        add(form);
        final FeedbackPanel feedbackPanel = new FeedbackPanel("feedback");
        add(feedbackPanel);
        PropertyModel<Address> address = new PropertyModel<Address>(getOrderModel(), "shippingAddress");

        form.add(new TextField<String>("name", new PropertyModel<String>(address, "name")).setRequired(true));
        form.add(new TextField<String>("street", new PropertyModel<String>(address, "street")).setRequired(true));
        form.add(new TextField<String>("zipcode", new PropertyModel<String>(address, "zipcode")).setRequired(true));
        form.add(new TextField<String>("city", new PropertyModel<String>(address, "city")).setRequired(true));
        form.add(new TextField<String>("email", new PropertyModel<String>(getOrderModel(), "email")).add(new EmailValidator()));
        form.add(new TextField<String>("coupon", new PropertyModel<String>(getOrderModel(), "coupon")).setRequired(false));

        form.add(new Link<String>("cancel") {
            @Override
            public void onClick() {
                setResponsePage(CheesePage.class);
            }
        });
        form.add(new Button("order") {
            @Override
            public void onSubmit() {
                Order order = getOrderModel().getObject();
                //
                try {
                    getOrderService().checkoutOrder(order);
                    setResponsePage(CheesePage.class);
                    getSession().invalidate();
                } catch (Exception ex) {
                    error("Unable to order your Products: " + ex.getMessage());
                }
                //
            }
        });
        add(new ShoppingCartPanel("cart", getOrderModel()));
    }
}
