package com.cheesr.layers.web.pages;

import org.apache.wicket.PageParameters;
import org.apache.wicket.markup.html.basic.Label;
import org.apache.wicket.markup.html.link.BookmarkablePageLink;
import org.apache.wicket.markup.html.link.ExternalLink;
import org.apache.wicket.markup.html.link.Link;

import com.cheesr.layers.domain.order.Order;
import com.cheesr.layers.domain.product.Cheese;
import com.cheesr.layers.web.model.CheeseModel;
import com.cheesr.layers.web.panels.ShoppingCartPanel;

/**
 * @author Erik
 *
 */
public class CheeseDetailPage extends CheesrPage {

	private CheeseModel model;
	
	public CheeseDetailPage(PageParameters pp) {
		model = new CheeseModel(pp.getAsLong("id")); 
		
		Cheese cheese=model.getObject();
        this.add(new Label("name", cheese.getName()));
        this.add(new Label("description", cheese.getDescription()));
        this.add(new Label("price", CURRENCY_SYMBOL + cheese.getPrice()));

        this.add(new Link<Cheese>("add", model) {

            /** After clicking the add button, add this cheese to the cart. */
            @Override
            public void onClick() {
                Cheese selected = getModelObject();
                Order order = getOrderModel().getObject();
                order.addProduct(selected);
                getOrderService().updateOrder(order);
            }
        });

        this.add(new ExternalLink("specs", "./download/?id=" + cheese.getId() + ".pdf"));

        add(new ShoppingCartPanel("cart", getOrderModel()));
        add(new Link<String>("checkout") {

            /** After clicking checkout, go to the Checkout page. */
            @Override
            public void onClick() {
                setResponsePage(new CheckoutPage());
            }

            /** Only display this button if the cart has something in it. */
            @Override
            public boolean isVisible() {
                return !getOrderModel().getObject().getOrderProducts().isEmpty();
            }
        });
        
        add(new BookmarkablePageLink<Void>("back",CheesePage.class));

		
	}
	
}
