package com.cheesr.layers.web.pages;

import java.util.Collections;

import org.apache.wicket.PageParameters;
import org.apache.wicket.markup.html.basic.Label;
import org.apache.wicket.markup.html.form.Button;
import org.apache.wicket.markup.html.form.Form;
import org.apache.wicket.markup.html.form.TextField;
import org.apache.wicket.markup.html.link.BookmarkablePageLink;
import org.apache.wicket.markup.html.link.Link;
import org.apache.wicket.markup.html.list.ListItem;
import org.apache.wicket.markup.html.list.PageableListView;
import org.apache.wicket.markup.html.navigation.paging.PagingNavigator;
import org.apache.wicket.model.Model;

import com.cheesr.layers.domain.order.Order;
import com.cheesr.layers.domain.product.Cheese;
import com.cheesr.layers.web.model.CheeseListModel;
import com.cheesr.layers.web.panels.ShoppingCartPanel;

/**
 * The home page for this Bad-Cheesr application.
 */
public class CheesePage extends CheesrPage {

    private Model<String> searchModel = new Model<String>("");
	

    public CheesePage() {
    	
        add(new BookmarkablePageLink<Void>("admin", OrdersPage.class));

        PageableListView<Cheese> cheeses = new PageableListView<Cheese>("cheeses", new CheeseListModel(searchModel), 5) {
            private static final long serialVersionUID = 1L;

            @Override
            protected void populateItem(ListItem<Cheese> item) {
                Cheese cheese = item.getModelObject();
                item.add(new Label("name", cheese.getName()));
                item.add(new Label("description", cheese.getDescription()));
                item.add(new Label("price", CURRENCY_SYMBOL + cheese.getPrice()));

                item.add(new Link<Cheese>("add", item.getModel()) {

                    /** After clicking the add button, add this cheese to the cart. */
                    @Override
                    public void onClick() {
                        Cheese selected = getModelObject();
                        Order order = getOrderModel().getObject();
                        order.addProduct(selected);
                        getOrderService().updateOrder(order);
                    }
                });

				item.add(new BookmarkablePageLink<Cheese>("details",CheeseDetailPage.class, new PageParameters(Collections.singletonMap("id", item.getModelObject().getId()))));
            }
        };
        Form<Void> form=new Form<Void>("form") {
        	protected void onSubmit() {
        		//
        	};
        };        
        form.add(new TextField<String>("search",searchModel));
        form.add(new Button("dosearch"));
        add(form);
        //
        add(cheeses);
        add(new PagingNavigator("navigator", cheeses));
        add(new ShoppingCartPanel("cart", getOrderModel()));
        add(new Link<String>("checkout") {

            @Override
            public void onClick() {
                setResponsePage(new CheckoutPage());
            }

            @Override
            public boolean isVisible() {
                return !getOrderModel().getObject().getOrderProducts().isEmpty();
            }
        });
    }
}
