package com.cheesr.layers.web.pages;

import org.apache.wicket.markup.html.WebPage;
import org.apache.wicket.spring.injection.annot.SpringBean;

import com.cheesr.layers.service.OrderService;
import com.cheesr.layers.service.ProductService;
import com.cheesr.layers.web.BadCheesrSession;
import com.cheesr.layers.web.model.OrderModel;

/**
 * This is the base page used by all of our application pages. It's a nice design pattern for
 * wicket. The provided methods make it easy for each page to get the session instance and any other
 * application-level state.
 */
public abstract class CheesrPage extends WebPage {

    public static final String CURRENCY_SYMBOL = "€ ";

    private OrderModel order;

    @SpringBean(name = "orderService")
    private OrderService orderService;

    @SpringBean(name = "productService")
    private ProductService productService;

    public CheesrPage() {
        super();
        Long oid = getCheesrSession().getOrderId();
        if (oid == null) {
            oid = orderService.createOrder().getId();
            getCheesrSession().setOrderId(oid);
        }
        order = new OrderModel(oid);
    }

    @Override
    protected void onDetach() {
        super.onDetach();
        order.detach();
    }

    public BadCheesrSession getCheesrSession() {
        return (BadCheesrSession) getSession();
    }

    public OrderService getOrderService() {
        return orderService;
    }

    public ProductService getProductService() {
        return productService;
    }

    public OrderModel getOrderModel() {
        return order;
    }
}
