package com.cheesr.layers.web.pages;

import java.util.List;

import org.apache.commons.lang.StringUtils;
import org.apache.wicket.PageParameters;
import org.apache.wicket.WicketRuntimeException;
import org.apache.wicket.behavior.SimpleAttributeModifier;
import org.apache.wicket.markup.html.basic.Label;
import org.apache.wicket.markup.html.include.Include;
import org.apache.wicket.markup.html.link.BookmarkablePageLink;
import org.apache.wicket.markup.html.link.Link;
import org.apache.wicket.markup.html.list.ListItem;
import org.apache.wicket.markup.html.list.ListView;
import org.apache.wicket.model.IModel;
import org.apache.wicket.model.PropertyModel;

import com.cheesr.layers.domain.order.Order;
import com.cheesr.layers.domain.product.Product;
import com.cheesr.layers.web.model.OrderModel;

/**
 * @author Erik
 *
 */
public class OrderDetailPage extends CheesrPage {

    private OrderModel model;

    public OrderDetailPage(PageParameters pp) {
        model = new OrderModel(pp.getAsLong("id"));

        Order order = model.getObject();
        this.add(new Label("id", String.valueOf(order.getShippingAddress().getId())));
        this.add(new Label("name", order.getShippingAddress().getName()));
        this.add(new Label("street", order.getShippingAddress().getStreet()));
        this.add(new Label("zipcode", order.getShippingAddress().getZipcode()));
        this.add(new Label("city", order.getShippingAddress().getCity()));

        this.add(new Include("coupon", StringUtils.isEmpty(order.getCoupon()) ? "" : "./coupons/" + order.getCoupon() + ".html") {
            @Override
            protected String importAsString() {
                if (StringUtils.isEmpty(getDefaultModelObjectAsString())) {
                    return "";
                }
                try {
                    return super.importAsString();
                } catch (WicketRuntimeException ex) {
                    return String.format("<i>Bad Coupon Code '%s' </i>", getDefaultModelObjectAsString());
                }
            }
        });

        IModel<? extends List<? extends Product>> productsModel = new PropertyModel<List<Product>>(model, "orderProducts");
        this.add(new ListView<Product>("products", productsModel) {
            @Override
            protected void populateItem(ListItem<Product> item) {
                Product cheese = item.getModelObject();
                item.add(new Label("name", cheese.getName()));
                item.add(new Label("price", CURRENCY_SYMBOL + cheese.getPrice()));
            }
        });
        
        this.add(new Link<Order>("fulfill", model) {

            @Override
            public void onClick() {
                getOrderService().fulfillOrder(getModelObject());
                setResponsePage(OrdersPage.class);
            }
        });

        Link<Order> cancelOrderLInk = new Link<Order>("cancel", model) {
            @Override
            public void onClick() {
                getOrderService().cancelOrder(getModelObject());
                setResponsePage(OrdersPage.class);
            }
        };
        cancelOrderLInk.add(new SimpleAttributeModifier("onclick", "return confirm('Are you sure you want to cancel the Order from "
                + model.getObject().getShippingAddress().getName() + "?');"));

        this.add(cancelOrderLInk);

        add(new BookmarkablePageLink<Void>("back", OrdersPage.class));

    }

}
