package com.cheesr.layers.web.pages;

import java.util.Collections;

import org.apache.wicket.PageParameters;
import org.apache.wicket.RequestCycle;
import org.apache.wicket.markup.html.basic.Label;
import org.apache.wicket.markup.html.form.Button;
import org.apache.wicket.markup.html.form.Form;
import org.apache.wicket.markup.html.form.TextField;
import org.apache.wicket.markup.html.link.BookmarkablePageLink;
import org.apache.wicket.markup.html.link.ExternalLink;
import org.apache.wicket.markup.html.list.ListItem;
import org.apache.wicket.markup.html.list.PageableListView;
import org.apache.wicket.markup.html.navigation.paging.PagingNavigator;
import org.apache.wicket.model.Model;
import org.apache.wicket.protocol.http.WebRequest;

import com.cheesr.layers.domain.order.Order;
import com.cheesr.layers.domain.product.Cheese;
import com.cheesr.layers.web.model.OrderListModel;

/**
 * @author Erik
 */
public class OrdersPage extends CheesrPage {

	private Model<String> searchModel = new Model<String>("");
	
    public OrdersPage() {
    	
        PageableListView<Order> orders = new PageableListView<Order>("orders", new OrderListModel(searchModel), 5) {
            private static final long serialVersionUID = 1L;

            @Override
            protected void populateItem(ListItem<Order> item) {
                Order order = item.getModelObject();
                item.add(new Label("id", String.valueOf(order.getId())));
                item.add(new Label("name", order.getShippingAddress().getName()).setEscapeModelStrings(false));

                item.add(new BookmarkablePageLink<Cheese>("open", OrderDetailPage.class, new PageParameters(Collections.singletonMap("id", item
                        .getModelObject().getId()))));
            }
        };
        Form<Void> form=new Form<Void>("form");        
        form.add(new TextField<String>("search",searchModel));
        form.add(new Button("dosearch"));
        add(form);
        this.add(new ExternalLink("fincancials", getRelativeToRoot() + "financials/?zap-financials.txt"));
        //
        add(orders);
        add(new PagingNavigator("navigator", orders));
    }

    public String getRelativeToRoot() {
        return ((WebRequest) RequestCycle.get().getRequest()).getRelativePathPrefixToContextRoot();
    }
}
