package com.cheesr.layers.web.panels;

import java.text.NumberFormat;
import java.util.List;

import org.apache.wicket.markup.html.basic.Label;
import org.apache.wicket.markup.html.link.Link;
import org.apache.wicket.markup.html.list.ListItem;
import org.apache.wicket.markup.html.list.ListView;
import org.apache.wicket.markup.html.panel.Panel;
import org.apache.wicket.model.Model;
import org.apache.wicket.model.PropertyModel;
import org.apache.wicket.spring.injection.annot.SpringBean;

import com.cheesr.layers.domain.order.Order;
import com.cheesr.layers.domain.product.Cheese;
import com.cheesr.layers.service.OrderService;
import com.cheesr.layers.web.model.OrderModel;
import com.cheesr.layers.web.pages.CheesrPage;

/**
 * A panel containing the list of cheeses that you've selected.
 */
public class ShoppingCartPanel extends Panel {

    @SpringBean(name = "orderService")
    private OrderService orderService;

    private OrderModel order;

    public ShoppingCartPanel(String id, OrderModel order) {
        super(id);
        this.order = order;
        add(new ListView<Cheese>("cart", new PropertyModel<List<Cheese>>(this, "order.orderProducts")) {

            @Override
            protected void populateItem(ListItem<Cheese> item) {
                Cheese cheese = item.getModelObject();
                item.add(new Label("name", cheese.getName()));
                item.add(new Label("price", CheesrPage.CURRENCY_SYMBOL + cheese.getPrice()));

                item.add(new Link<Cheese>("remove", item.getModel()) {
                    @Override
                    public void onClick() {
                        Cheese selected = getModelObject();
                        Order order = getOrder();
                        order.removeProduct(selected);
                        orderService.updateOrder(order);
                    }
                });
            }
        });
        add(new Label("total", new Model<String>() {
            @Override
            public String getObject() {
                NumberFormat nf = NumberFormat.getInstance();
                return CheesrPage.CURRENCY_SYMBOL + nf.format(getOrder().getTotal());
            }
        }));
    }

    public Order getOrder() {
        return order.getObject();
    }
}
