package com.cheesr.layers.domain;

import static org.junit.Assert.assertNotNull;

import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.io.Serializable;

import org.junit.Test;
import org.springframework.beans.factory.annotation.Autowired;

import com.cheesr.layers.AbstractSpringContextTestCase;
import com.cheesr.layers.domain.product.Cheese;
import com.cheesr.layers.service.ProductService;

/**
 * answers the question on what happens if you serialize a domain object.
 * The answer is that it will work just fine, the Hibernate Bags hold a 
 * transient link to the session which will not be serialized. Smart.
 * @author E.Hooijmeijer
 */
public class DomainSerializationTest extends AbstractSpringContextTestCase {

    @Autowired
    private ProductService productService;

    @Test
    public void shouldSerialize() throws Exception {
        // Don't bother if cheese isn't serializable.
        if (!Serializable.class.isAssignableFrom(Cheese.class)) return;
        //
        Cheese c = productService.getAllCheeses().get(0);
        ByteArrayOutputStream bytes = new ByteArrayOutputStream();
        ObjectOutputStream out = new ObjectOutputStream(bytes);
        try {
            out.writeObject(c);
        } finally {
            out.close();
        }
        //
        System.out.println(bytes.toByteArray().length + " bytes");
        //System.out.println(new String(bytes.toByteArray(), Charset.forName("cp1258")));
        //
        ObjectInputStream in = new ObjectInputStream(new ByteArrayInputStream(bytes.toByteArray()));
        try {
            Cheese copy = (Cheese) in.readObject();
            assertNotNull(copy.getId());
            assertNotNull(copy.getName());
            assertNotNull(copy.getDescription());
            assertNotNull(copy.getPrice());
            assertNotNull(copy.getVersion());
            //System.out.println(copy.getMatchingWines().size()); // Fails - LazyInit
        } finally {
            in.close();
        }
    }
}
