package com.cheesr.layers.service;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertTrue;

import java.util.List;

import junit.framework.Assert;

import org.junit.Test;
import org.springframework.beans.factory.annotation.Autowired;

import com.cheesr.layers.AbstractSpringContextTestCase;
import com.cheesr.layers.domain.order.Order;
import com.cheesr.layers.domain.product.Product;

public class OrderServiceImplTest extends AbstractSpringContextTestCase {

    @Autowired
    private ProductService productService;

    @Autowired
    private OrderService orderService;

    @Test
    public void testContext() throws Exception {
        Assert.assertNotNull(productService);
        Assert.assertNotNull(orderService);
    }

    private Order makeOrderWithProducts() {
        List<Product> p = productService.getAllProducts();
        Order order = orderService.createOrder();
        order.getOrderProducts().add(p.get(0));
        orderService.updateOrder(order);
        return orderService.findById(order.getId());
    }

    @Test
    public void shouldAddProducts() {
        Order order = makeOrderWithProducts();
        //
        assertEquals(order.getId(), orderService.findById(order.getId()).getId());
        assertEquals(1, orderService.findById(order.getId()).getOrderProducts().size());
    }

    @Test
    public void shouldRemoveProducts() {
        Order o = makeOrderWithProducts();
        o.getOrderProducts().remove(0);
        orderService.updateOrder(o);
        //
        assertEquals(0, orderService.findById(o.getId()).getOrderProducts().size());
    }

    @Test
    public void shouldUpdateAddress() {
        Order order = orderService.createOrder();
        //
        order.getShippingAddress().setCity("Ergens");
        order.getShippingAddress().setName("Ergens");
        order.getShippingAddress().setStreet("Ergens");
        order.getShippingAddress().setZipcode("Ergens");
        //
        orderService.updateOrder(order);
        //
        assertEquals("Ergens", orderService.findById(order.getId()).getShippingAddress().getCity());
    }

    @Test
    public void shouldCheckoutOrder() {
        Order order = makeOrderWithProducts();
        //
        order.getShippingAddress().setCity("Ergens");
        order.getShippingAddress().setName("Ergens");
        order.getShippingAddress().setStreet("Ergens");
        order.getShippingAddress().setZipcode("Ergens");
        //
        orderService.checkoutOrder(order);
        //
        assertTrue(orderService.findById(order.getId()).isOrdered());
    }

    //    @Test
    //    public void inspect() throws Exception {
    //        DatabaseManagerSwing.main(new String[0]);
    //        while (true) {
    //            Thread.sleep(100L);
    //        }
    //    }
}
