package com.cheesr.layers.service;

import static org.junit.Assert.assertTrue;

import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.io.Serializable;

import org.junit.Test;
import org.springframework.beans.factory.annotation.Autowired;

import com.cheesr.layers.AbstractSpringContextTestCase;

/**
 * Answers the question of what would happen if you would serialize a
 * service. Amazingly, it just works, at the cost of 4k bytes. The
 * byte array contains lots of interesting framework classes.  
 * @author E.Hooijmeijer
 */
public class ServiceSerializationTest extends AbstractSpringContextTestCase {

    @Autowired
    private ProductService productService;

    @Test
    public void shouldSerialize() throws Exception {
        // Don't bother if productService isn't serializable.
        if (!Serializable.class.isAssignableFrom(ProductService.class)) return;
        //
        assertTrue(productService.getAllProducts().size() > 0);
        //
        ByteArrayOutputStream bytes = new ByteArrayOutputStream();
        ObjectOutputStream out = new ObjectOutputStream(bytes);
        try {
            out.writeObject(productService);
        } finally {
            out.close();
        }
        //
        System.out.println(bytes.toByteArray().length + " bytes");
        //dump(new String(bytes.toByteArray(), Charset.forName("cp1258")));
        //
        ObjectInputStream in = new ObjectInputStream(new ByteArrayInputStream(bytes.toByteArray()));
        try {
            ProductService copy = (ProductService) in.readObject();
            assertTrue(copy.getAllProducts().size() > 0);
        } finally {
            in.close();
        }
    }

    protected void dump(String string) {
        boolean non = false;
        for (int t = 0; t < string.length(); t++) {
            char c = string.charAt(t);
            if ((c >= 32) && (c < 128)) {
                if (non) System.out.println();
                System.out.print(c);
                non = false;
            } else {
                non = true;
            }
        }
    }
}
