package com.cheesr.layers.web;

import org.apache.wicket.spring.injection.annot.SpringComponentInjector;
import org.apache.wicket.spring.test.ApplicationContextMock;
import org.apache.wicket.util.tester.WicketTester;
import org.junit.Before;

/**
 * Abstract test case for Wicket components.
 */
public abstract class AbstractWicketTestCase {

    /**
     * Wicket tester instance.
     */
    protected WicketTester tester;

    /**
     * Set up the wicket extensions tester, using a mocked application context.
     */
    @Before
    public void setUpWicketTester() {
        ApplicationContextMock context = new ApplicationContextMock();
        this.configureBeans(context);
        CheesrApplicationStub application = new CheesrApplicationStub(context);
        tester = new WicketTester(application);
    }

    /**
     * Configure beans in application context. Each field annotated with a @SpringBean
     * has to be available inside this context, or an exception will be thrown.
     * @param context {@link ApplicationContextMock}
     */
    protected void configureBeans(ApplicationContextMock context) {
        // Overwrite to configure additional beans
    }

    /**
     * Stub implementation of {@link WicketApplication}, which uses an {@link ApplicationContextMock}
     * rather than a class-path scanning application context.
     */
    private class CheesrApplicationStub extends BadCheesrApplication {

        /**
         * Application context mock, containing all mocked beans.
         */
        private final ApplicationContextMock context;

        /**
         * Construct a new {@link CheesrApplicationStub}.
         * @param context Application context mock
         */
        public CheesrApplicationStub(ApplicationContextMock context) {
            this.context = context;
        }

        /**
         * {@inheritDoc}
         */
        @Override
        protected void configureComponentInjector() {
            this.addComponentInstantiationListener(new SpringComponentInjector(this, context, true));
        }

        /**
         * {@inheritDoc}
         */
        @Override
        public String getConfigurationType() {
            return "deployment";
        }

    }

}
