package com.cheesr.layers.web;

import java.lang.reflect.Field;
import java.util.ArrayList;

import org.apache.wicket.spring.test.ApplicationContextMock;
import org.easymock.EasyMock;
import org.junit.Test;
import org.springframework.util.ReflectionUtils;

import com.cheesr.layers.domain.order.Order;
import com.cheesr.layers.domain.product.Cheese;
import com.cheesr.layers.service.OrderService;
import com.cheesr.layers.service.ProductService;
import com.cheesr.layers.web.pages.CheesePage;

/**
 * Test case for {@link HomePage}.
 */
public class HomePageTest extends AbstractWicketTestCase {

    private ProductService productServiceMock;
    private OrderService orderServiceMock;

    /**
     * {@inheritDoc}
     */
    @Override
    protected void configureBeans(ApplicationContextMock context) {
        super.configureBeans(context);
        productServiceMock = EasyMock.createMock(ProductService.class);
        context.putBean("productService", productServiceMock);
        orderServiceMock = EasyMock.createMock(OrderService.class);
        context.putBean("orderService", orderServiceMock);
    }

    private Order createOrder() {
        Order order = new Order();
        setFieldValue(order, "id", 1L);
        return order;
    }

    public static void setFieldValue(Object target, String fieldName, Object newValue) {
        Field field = ReflectionUtils.findField(target.getClass(), fieldName);
        if (field == null) {
            String message = String.format("%s has not declared a '%s' field", target.getClass().getName(), fieldName);
            throw new IllegalArgumentException(message);
        }
        ReflectionUtils.makeAccessible(field);
        ReflectionUtils.setField(field, target, newValue);
    }

    @Test
    public void testRender() {
        //
        Order order = createOrder();
        // 
        // Set the expected calls on the service layer.
        //
        EasyMock.expect(orderServiceMock.createOrder()).andReturn(order);
        EasyMock.expect(productServiceMock.getAllCheeses()).andReturn(new ArrayList<Cheese>());
        EasyMock.expect(orderServiceMock.findById(1L)).andReturn(order);
        //
        // Set it in replay mode.
        //
        EasyMock.replay(productServiceMock, orderServiceMock);
        //
        // Perform actual test
        //
        tester.startPage(CheesePage.class);
        tester.assertRenderedPage(CheesePage.class);
        //
        // Verify if all methods were called.
        //
        EasyMock.verify(productServiceMock, orderServiceMock);
    }

}